// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: op_def.proto
// Protobuf C++ Version: 6.32.1

#include "op_def.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
namespace opencv_tensorflow {

inline constexpr OpDeprecation::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        explanation_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        version_{0} {}

template <typename>
PROTOBUF_CONSTEXPR OpDeprecation::OpDeprecation(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(OpDeprecation_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(::_pbi::ConstantInitialized()) {
}
struct OpDeprecationDefaultTypeInternal {
  PROTOBUF_CONSTEXPR OpDeprecationDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~OpDeprecationDefaultTypeInternal() {}
  union {
    OpDeprecation _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 OpDeprecationDefaultTypeInternal _OpDeprecation_default_instance_;

inline constexpr OpDef_ArgDef::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        description_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        type_attr_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        number_attr_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        type_list_attr_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        type_{static_cast< ::opencv_tensorflow::DataType >(0)},
        is_ref_{false} {}

template <typename>
PROTOBUF_CONSTEXPR OpDef_ArgDef::OpDef_ArgDef(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(OpDef_ArgDef_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(::_pbi::ConstantInitialized()) {
}
struct OpDef_ArgDefDefaultTypeInternal {
  PROTOBUF_CONSTEXPR OpDef_ArgDefDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~OpDef_ArgDefDefaultTypeInternal() {}
  union {
    OpDef_ArgDef _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 OpDef_ArgDefDefaultTypeInternal _OpDef_ArgDef_default_instance_;

inline constexpr OpDef_AttrDef::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        type_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        description_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        default_value_{nullptr},
        allowed_values_{nullptr},
        minimum_{::int64_t{0}},
        has_minimum_{false} {}

template <typename>
PROTOBUF_CONSTEXPR OpDef_AttrDef::OpDef_AttrDef(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(OpDef_AttrDef_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(::_pbi::ConstantInitialized()) {
}
struct OpDef_AttrDefDefaultTypeInternal {
  PROTOBUF_CONSTEXPR OpDef_AttrDefDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~OpDef_AttrDefDefaultTypeInternal() {}
  union {
    OpDef_AttrDef _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 OpDef_AttrDefDefaultTypeInternal _OpDef_AttrDef_default_instance_;

inline constexpr OpDef::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        input_arg_{},
        output_arg_{},
        attr_{},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        summary_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        description_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        deprecation_{nullptr},
        is_aggregate_{false},
        is_stateful_{false},
        is_commutative_{false},
        allows_uninitialized_input_{false} {}

template <typename>
PROTOBUF_CONSTEXPR OpDef::OpDef(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(OpDef_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(::_pbi::ConstantInitialized()) {
}
struct OpDefDefaultTypeInternal {
  PROTOBUF_CONSTEXPR OpDefDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~OpDefDefaultTypeInternal() {}
  union {
    OpDef _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 OpDefDefaultTypeInternal _OpDef_default_instance_;

inline constexpr OpList::Impl_::Impl_(
    ::_pbi::ConstantInitialized) noexcept
      : op_{},
        _cached_size_{0} {}

template <typename>
PROTOBUF_CONSTEXPR OpList::OpList(::_pbi::ConstantInitialized)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(OpList_class_data_.base()),
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(),
#endif  // PROTOBUF_CUSTOM_VTABLE
      _impl_(::_pbi::ConstantInitialized()) {
}
struct OpListDefaultTypeInternal {
  PROTOBUF_CONSTEXPR OpListDefaultTypeInternal() : _instance(::_pbi::ConstantInitialized{}) {}
  ~OpListDefaultTypeInternal() {}
  union {
    OpList _instance;
  };
};

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 OpListDefaultTypeInternal _OpList_default_instance_;
}  // namespace opencv_tensorflow
static constexpr const ::_pb::EnumDescriptor *PROTOBUF_NONNULL *PROTOBUF_NULLABLE
    file_level_enum_descriptors_op_5fdef_2eproto = nullptr;
static constexpr const ::_pb::ServiceDescriptor *PROTOBUF_NONNULL *PROTOBUF_NULLABLE
    file_level_service_descriptors_op_5fdef_2eproto = nullptr;
const ::uint32_t
    TableStruct_op_5fdef_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_ArgDef, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_ArgDef, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_ArgDef, _impl_.description_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_ArgDef, _impl_.type_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_ArgDef, _impl_.type_attr_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_ArgDef, _impl_.number_attr_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_ArgDef, _impl_.type_list_attr_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_ArgDef, _impl_.is_ref_),
        0,
        1,
        5,
        2,
        3,
        4,
        6,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_AttrDef, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_AttrDef, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_AttrDef, _impl_.type_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_AttrDef, _impl_.default_value_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_AttrDef, _impl_.description_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_AttrDef, _impl_.has_minimum_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_AttrDef, _impl_.minimum_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef_AttrDef, _impl_.allowed_values_),
        0,
        1,
        3,
        2,
        6,
        5,
        4,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_._has_bits_),
        14, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.input_arg_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.output_arg_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.attr_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.deprecation_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.summary_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.description_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.is_commutative_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.is_aggregate_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.is_stateful_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDef, _impl_.allows_uninitialized_input_),
        0,
        ~0u,
        ~0u,
        ~0u,
        3,
        1,
        2,
        6,
        4,
        5,
        7,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDeprecation, _impl_._has_bits_),
        5, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDeprecation, _impl_.version_),
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpDeprecation, _impl_.explanation_),
        1,
        0,
        0x000, // bitmap
        PROTOBUF_FIELD_OFFSET(::opencv_tensorflow::OpList, _impl_.op_),
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::opencv_tensorflow::OpDef_ArgDef)},
        {17, sizeof(::opencv_tensorflow::OpDef_AttrDef)},
        {34, sizeof(::opencv_tensorflow::OpDef)},
        {59, sizeof(::opencv_tensorflow::OpDeprecation)},
        {66, sizeof(::opencv_tensorflow::OpList)},
};
static const ::_pb::Message* PROTOBUF_NONNULL const file_default_instances[] = {
    &::opencv_tensorflow::_OpDef_ArgDef_default_instance_._instance,
    &::opencv_tensorflow::_OpDef_AttrDef_default_instance_._instance,
    &::opencv_tensorflow::_OpDef_default_instance_._instance,
    &::opencv_tensorflow::_OpDeprecation_default_instance_._instance,
    &::opencv_tensorflow::_OpList_default_instance_._instance,
};
const char descriptor_table_protodef_op_5fdef_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n\014op_def.proto\022\021opencv_tensorflow\032\020attr_"
    "value.proto\032\013types.proto\"\351\005\n\005OpDef\022\014\n\004na"
    "me\030\001 \001(\t\0222\n\tinput_arg\030\002 \003(\0132\037.opencv_ten"
    "sorflow.OpDef.ArgDef\0223\n\noutput_arg\030\003 \003(\013"
    "2\037.opencv_tensorflow.OpDef.ArgDef\022.\n\004att"
    "r\030\004 \003(\0132 .opencv_tensorflow.OpDef.AttrDe"
    "f\0225\n\013deprecation\030\010 \001(\0132 .opencv_tensorfl"
    "ow.OpDeprecation\022\017\n\007summary\030\005 \001(\t\022\023\n\013des"
    "cription\030\006 \001(\t\022\026\n\016is_commutative\030\022 \001(\010\022\024"
    "\n\014is_aggregate\030\020 \001(\010\022\023\n\013is_stateful\030\021 \001("
    "\010\022\"\n\032allows_uninitialized_input\030\023 \001(\010\032\246\001"
    "\n\006ArgDef\022\014\n\004name\030\001 \001(\t\022\023\n\013description\030\002 "
    "\001(\t\022)\n\004type\030\003 \001(\0162\033.opencv_tensorflow.Da"
    "taType\022\021\n\ttype_attr\030\004 \001(\t\022\023\n\013number_attr"
    "\030\005 \001(\t\022\026\n\016type_list_attr\030\006 \001(\t\022\016\n\006is_ref"
    "\030\020 \001(\010\032\313\001\n\007AttrDef\022\014\n\004name\030\001 \001(\t\022\014\n\004type"
    "\030\002 \001(\t\0223\n\rdefault_value\030\003 \001(\0132\034.opencv_t"
    "ensorflow.AttrValue\022\023\n\013description\030\004 \001(\t"
    "\022\023\n\013has_minimum\030\005 \001(\010\022\017\n\007minimum\030\006 \001(\003\0224"
    "\n\016allowed_values\030\007 \001(\0132\034.opencv_tensorfl"
    "ow.AttrValue\"5\n\rOpDeprecation\022\017\n\007version"
    "\030\001 \001(\005\022\023\n\013explanation\030\002 \001(\t\".\n\006OpList\022$\n"
    "\002op\030\001 \003(\0132\030.opencv_tensorflow.OpDefB,\n\030o"
    "rg.tensorflow.frameworkB\013OpDefProtosP\001\370\001"
    "\001b\006proto3"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_op_5fdef_2eproto_deps[2] = {
        &::descriptor_table_attr_5fvalue_2eproto,
        &::descriptor_table_types_2eproto,
};
static ::absl::once_flag descriptor_table_op_5fdef_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_op_5fdef_2eproto = {
    false,
    false,
    969,
    descriptor_table_protodef_op_5fdef_2eproto,
    "op_def.proto",
    &descriptor_table_op_5fdef_2eproto_once,
    descriptor_table_op_5fdef_2eproto_deps,
    2,
    5,
    schemas,
    file_default_instances,
    TableStruct_op_5fdef_2eproto::offsets,
    file_level_enum_descriptors_op_5fdef_2eproto,
    file_level_service_descriptors_op_5fdef_2eproto,
};
namespace opencv_tensorflow {
// ===================================================================

class OpDef_ArgDef::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<OpDef_ArgDef>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_._has_bits_);
};

OpDef_ArgDef::OpDef_ArgDef(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, OpDef_ArgDef_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opencv_tensorflow.OpDef.ArgDef)
}
PROTOBUF_NDEBUG_INLINE OpDef_ArgDef::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opencv_tensorflow::OpDef_ArgDef& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        name_(arena, from.name_),
        description_(arena, from.description_),
        type_attr_(arena, from.type_attr_),
        number_attr_(arena, from.number_attr_),
        type_list_attr_(arena, from.type_list_attr_) {}

OpDef_ArgDef::OpDef_ArgDef(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const OpDef_ArgDef& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, OpDef_ArgDef_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  OpDef_ArgDef* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::memcpy(reinterpret_cast<char *>(&_impl_) +
               offsetof(Impl_, type_),
           reinterpret_cast<const char *>(&from._impl_) +
               offsetof(Impl_, type_),
           offsetof(Impl_, is_ref_) -
               offsetof(Impl_, type_) +
               sizeof(Impl_::is_ref_));

  // @@protoc_insertion_point(copy_constructor:opencv_tensorflow.OpDef.ArgDef)
}
PROTOBUF_NDEBUG_INLINE OpDef_ArgDef::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        name_(arena),
        description_(arena),
        type_attr_(arena),
        number_attr_(arena),
        type_list_attr_(arena) {}

inline void OpDef_ArgDef::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char *>(&_impl_) +
               offsetof(Impl_, type_),
           0,
           offsetof(Impl_, is_ref_) -
               offsetof(Impl_, type_) +
               sizeof(Impl_::is_ref_));
}
OpDef_ArgDef::~OpDef_ArgDef() {
  // @@protoc_insertion_point(destructor:opencv_tensorflow.OpDef.ArgDef)
  SharedDtor(*this);
}
inline void OpDef_ArgDef::SharedDtor(MessageLite& self) {
  OpDef_ArgDef& this_ = static_cast<OpDef_ArgDef&>(self);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.description_.Destroy();
  this_._impl_.type_attr_.Destroy();
  this_._impl_.number_attr_.Destroy();
  this_._impl_.type_list_attr_.Destroy();
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL OpDef_ArgDef::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) OpDef_ArgDef(arena);
}
constexpr auto OpDef_ArgDef::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(OpDef_ArgDef),
                                            alignof(OpDef_ArgDef));
}
constexpr auto OpDef_ArgDef::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_OpDef_ArgDef_default_instance_._instance,
          &_table_.header,
          nullptr,  // OnDemandRegisterArenaDtor
          nullptr,  // IsInitialized
          &OpDef_ArgDef::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<OpDef_ArgDef>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &OpDef_ArgDef::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<OpDef_ArgDef>(), &OpDef_ArgDef::ByteSizeLong,
              &OpDef_ArgDef::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_._cached_size_),
          false,
      },
      &OpDef_ArgDef::kDescriptorMethods,
      &descriptor_table_op_5fdef_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull OpDef_ArgDef_class_data_ =
        OpDef_ArgDef::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
OpDef_ArgDef::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&OpDef_ArgDef_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(OpDef_ArgDef_class_data_.tc_table);
  return OpDef_ArgDef_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 7, 0, 88, 2>
OpDef_ArgDef::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_._has_bits_),
    0, // no _extensions_
    16, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294934464,  // skipmap
    offsetof(decltype(_table_), field_entries),
    7,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    OpDef_ArgDef_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::opencv_tensorflow::OpDef_ArgDef>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // bool is_ref = 16;
    {::_pbi::TcParser::FastV8S2,
     {384, 6, 0, PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.is_ref_)}},
    // string name = 1;
    {::_pbi::TcParser::FastUS1,
     {10, 0, 0, PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.name_)}},
    // string description = 2;
    {::_pbi::TcParser::FastUS1,
     {18, 1, 0, PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.description_)}},
    // .opencv_tensorflow.DataType type = 3;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(OpDef_ArgDef, _impl_.type_), 5>(),
     {24, 5, 0, PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.type_)}},
    // string type_attr = 4;
    {::_pbi::TcParser::FastUS1,
     {34, 2, 0, PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.type_attr_)}},
    // string number_attr = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 3, 0, PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.number_attr_)}},
    // string type_list_attr = 6;
    {::_pbi::TcParser::FastUS1,
     {50, 4, 0, PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.type_list_attr_)}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // string name = 1;
    {PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // string description = 2;
    {PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.description_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // .opencv_tensorflow.DataType type = 3;
    {PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.type_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
    // string type_attr = 4;
    {PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.type_attr_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // string number_attr = 5;
    {PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.number_attr_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // string type_list_attr = 6;
    {PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.type_list_attr_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // bool is_ref = 16;
    {PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.is_ref_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
  }},
  // no aux_entries
  {{
    "\36\4\13\0\11\13\16\0"
    "opencv_tensorflow.OpDef.ArgDef"
    "name"
    "description"
    "type_attr"
    "number_attr"
    "type_list_attr"
  }},
};
PROTOBUF_NOINLINE void OpDef_ArgDef::Clear() {
// @@protoc_insertion_point(message_clear_start:opencv_tensorflow.OpDef.ArgDef)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if ((cached_has_bits & 0x0000001fU) != 0) {
    if ((cached_has_bits & 0x00000001U) != 0) {
      _impl_.name_.ClearNonDefaultToEmpty();
    }
    if ((cached_has_bits & 0x00000002U) != 0) {
      _impl_.description_.ClearNonDefaultToEmpty();
    }
    if ((cached_has_bits & 0x00000004U) != 0) {
      _impl_.type_attr_.ClearNonDefaultToEmpty();
    }
    if ((cached_has_bits & 0x00000008U) != 0) {
      _impl_.number_attr_.ClearNonDefaultToEmpty();
    }
    if ((cached_has_bits & 0x00000010U) != 0) {
      _impl_.type_list_attr_.ClearNonDefaultToEmpty();
    }
  }
  if ((cached_has_bits & 0x00000060U) != 0) {
    ::memset(&_impl_.type_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.is_ref_) -
        reinterpret_cast<char*>(&_impl_.type_)) + sizeof(_impl_.is_ref_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL OpDef_ArgDef::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const OpDef_ArgDef& this_ = static_cast<const OpDef_ArgDef&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL OpDef_ArgDef::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const OpDef_ArgDef& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opencv_tensorflow.OpDef.ArgDef)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  // string name = 1;
  if ((this_._impl_._has_bits_[0] & 0x00000001U) != 0) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.ArgDef.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string description = 2;
  if ((this_._impl_._has_bits_[0] & 0x00000002U) != 0) {
    if (!this_._internal_description().empty()) {
      const ::std::string& _s = this_._internal_description();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.ArgDef.description");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  // .opencv_tensorflow.DataType type = 3;
  if ((this_._impl_._has_bits_[0] & 0x00000020U) != 0) {
    if (this_._internal_type() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          3, this_._internal_type(), target);
    }
  }

  // string type_attr = 4;
  if ((this_._impl_._has_bits_[0] & 0x00000004U) != 0) {
    if (!this_._internal_type_attr().empty()) {
      const ::std::string& _s = this_._internal_type_attr();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.ArgDef.type_attr");
      target = stream->WriteStringMaybeAliased(4, _s, target);
    }
  }

  // string number_attr = 5;
  if ((this_._impl_._has_bits_[0] & 0x00000008U) != 0) {
    if (!this_._internal_number_attr().empty()) {
      const ::std::string& _s = this_._internal_number_attr();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.ArgDef.number_attr");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string type_list_attr = 6;
  if ((this_._impl_._has_bits_[0] & 0x00000010U) != 0) {
    if (!this_._internal_type_list_attr().empty()) {
      const ::std::string& _s = this_._internal_type_list_attr();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.ArgDef.type_list_attr");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // bool is_ref = 16;
  if ((this_._impl_._has_bits_[0] & 0x00000040U) != 0) {
    if (this_._internal_is_ref() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          16, this_._internal_is_ref(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opencv_tensorflow.OpDef.ArgDef)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t OpDef_ArgDef::ByteSizeLong(const MessageLite& base) {
  const OpDef_ArgDef& this_ = static_cast<const OpDef_ArgDef&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t OpDef_ArgDef::ByteSizeLong() const {
  const OpDef_ArgDef& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opencv_tensorflow.OpDef.ArgDef)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if ((cached_has_bits & 0x0000007fU) != 0) {
    // string name = 1;
    if ((cached_has_bits & 0x00000001U) != 0) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // string description = 2;
    if ((cached_has_bits & 0x00000002U) != 0) {
      if (!this_._internal_description().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_description());
      }
    }
    // string type_attr = 4;
    if ((cached_has_bits & 0x00000004U) != 0) {
      if (!this_._internal_type_attr().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_type_attr());
      }
    }
    // string number_attr = 5;
    if ((cached_has_bits & 0x00000008U) != 0) {
      if (!this_._internal_number_attr().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_number_attr());
      }
    }
    // string type_list_attr = 6;
    if ((cached_has_bits & 0x00000010U) != 0) {
      if (!this_._internal_type_list_attr().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_type_list_attr());
      }
    }
    // .opencv_tensorflow.DataType type = 3;
    if ((cached_has_bits & 0x00000020U) != 0) {
      if (this_._internal_type() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_type());
      }
    }
    // bool is_ref = 16;
    if ((cached_has_bits & 0x00000040U) != 0) {
      if (this_._internal_is_ref() != 0) {
        total_size += 3;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void OpDef_ArgDef::MergeImpl(::google::protobuf::MessageLite& to_msg, const ::google::protobuf::MessageLite& from_msg) {
  auto* const _this = static_cast<OpDef_ArgDef*>(&to_msg);
  auto& from = static_cast<const OpDef_ArgDef&>(from_msg);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    from.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:opencv_tensorflow.OpDef.ArgDef)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if ((cached_has_bits & 0x0000007fU) != 0) {
    if ((cached_has_bits & 0x00000001U) != 0) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if ((cached_has_bits & 0x00000002U) != 0) {
      if (!from._internal_description().empty()) {
        _this->_internal_set_description(from._internal_description());
      } else {
        if (_this->_impl_.description_.IsDefault()) {
          _this->_internal_set_description("");
        }
      }
    }
    if ((cached_has_bits & 0x00000004U) != 0) {
      if (!from._internal_type_attr().empty()) {
        _this->_internal_set_type_attr(from._internal_type_attr());
      } else {
        if (_this->_impl_.type_attr_.IsDefault()) {
          _this->_internal_set_type_attr("");
        }
      }
    }
    if ((cached_has_bits & 0x00000008U) != 0) {
      if (!from._internal_number_attr().empty()) {
        _this->_internal_set_number_attr(from._internal_number_attr());
      } else {
        if (_this->_impl_.number_attr_.IsDefault()) {
          _this->_internal_set_number_attr("");
        }
      }
    }
    if ((cached_has_bits & 0x00000010U) != 0) {
      if (!from._internal_type_list_attr().empty()) {
        _this->_internal_set_type_list_attr(from._internal_type_list_attr());
      } else {
        if (_this->_impl_.type_list_attr_.IsDefault()) {
          _this->_internal_set_type_list_attr("");
        }
      }
    }
    if ((cached_has_bits & 0x00000020U) != 0) {
      if (from._internal_type() != 0) {
        _this->_impl_.type_ = from._impl_.type_;
      }
    }
    if ((cached_has_bits & 0x00000040U) != 0) {
      if (from._internal_is_ref() != 0) {
        _this->_impl_.is_ref_ = from._impl_.is_ref_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void OpDef_ArgDef::CopyFrom(const OpDef_ArgDef& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:opencv_tensorflow.OpDef.ArgDef)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void OpDef_ArgDef::InternalSwap(OpDef_ArgDef* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.description_, &other->_impl_.description_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.type_attr_, &other->_impl_.type_attr_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.number_attr_, &other->_impl_.number_attr_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.type_list_attr_, &other->_impl_.type_list_attr_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.is_ref_)
      + sizeof(OpDef_ArgDef::_impl_.is_ref_)
      - PROTOBUF_FIELD_OFFSET(OpDef_ArgDef, _impl_.type_)>(
          reinterpret_cast<char*>(&_impl_.type_),
          reinterpret_cast<char*>(&other->_impl_.type_));
}

::google::protobuf::Metadata OpDef_ArgDef::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class OpDef_AttrDef::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<OpDef_AttrDef>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_._has_bits_);
};

void OpDef_AttrDef::clear_default_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.default_value_ != nullptr) _impl_.default_value_->Clear();
  _impl_._has_bits_[0] &= ~0x00000008U;
}
void OpDef_AttrDef::clear_allowed_values() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.allowed_values_ != nullptr) _impl_.allowed_values_->Clear();
  _impl_._has_bits_[0] &= ~0x00000010U;
}
OpDef_AttrDef::OpDef_AttrDef(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, OpDef_AttrDef_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opencv_tensorflow.OpDef.AttrDef)
}
PROTOBUF_NDEBUG_INLINE OpDef_AttrDef::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opencv_tensorflow::OpDef_AttrDef& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        name_(arena, from.name_),
        type_(arena, from.type_),
        description_(arena, from.description_) {}

OpDef_AttrDef::OpDef_AttrDef(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const OpDef_AttrDef& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, OpDef_AttrDef_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  OpDef_AttrDef* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.default_value_ = ((cached_has_bits & 0x00000008U) != 0)
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.default_value_)
                : nullptr;
  _impl_.allowed_values_ = ((cached_has_bits & 0x00000010U) != 0)
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.allowed_values_)
                : nullptr;
  ::memcpy(reinterpret_cast<char *>(&_impl_) +
               offsetof(Impl_, minimum_),
           reinterpret_cast<const char *>(&from._impl_) +
               offsetof(Impl_, minimum_),
           offsetof(Impl_, has_minimum_) -
               offsetof(Impl_, minimum_) +
               sizeof(Impl_::has_minimum_));

  // @@protoc_insertion_point(copy_constructor:opencv_tensorflow.OpDef.AttrDef)
}
PROTOBUF_NDEBUG_INLINE OpDef_AttrDef::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        name_(arena),
        type_(arena),
        description_(arena) {}

inline void OpDef_AttrDef::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char *>(&_impl_) +
               offsetof(Impl_, default_value_),
           0,
           offsetof(Impl_, has_minimum_) -
               offsetof(Impl_, default_value_) +
               sizeof(Impl_::has_minimum_));
}
OpDef_AttrDef::~OpDef_AttrDef() {
  // @@protoc_insertion_point(destructor:opencv_tensorflow.OpDef.AttrDef)
  SharedDtor(*this);
}
inline void OpDef_AttrDef::SharedDtor(MessageLite& self) {
  OpDef_AttrDef& this_ = static_cast<OpDef_AttrDef&>(self);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.type_.Destroy();
  this_._impl_.description_.Destroy();
  delete this_._impl_.default_value_;
  delete this_._impl_.allowed_values_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL OpDef_AttrDef::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) OpDef_AttrDef(arena);
}
constexpr auto OpDef_AttrDef::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(OpDef_AttrDef),
                                            alignof(OpDef_AttrDef));
}
constexpr auto OpDef_AttrDef::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_OpDef_AttrDef_default_instance_._instance,
          &_table_.header,
          nullptr,  // OnDemandRegisterArenaDtor
          nullptr,  // IsInitialized
          &OpDef_AttrDef::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<OpDef_AttrDef>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &OpDef_AttrDef::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<OpDef_AttrDef>(), &OpDef_AttrDef::ByteSizeLong,
              &OpDef_AttrDef::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_._cached_size_),
          false,
      },
      &OpDef_AttrDef::kDescriptorMethods,
      &descriptor_table_op_5fdef_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull OpDef_AttrDef_class_data_ =
        OpDef_AttrDef::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
OpDef_AttrDef::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&OpDef_AttrDef_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(OpDef_AttrDef_class_data_.tc_table);
  return OpDef_AttrDef_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<3, 7, 2, 59, 2>
OpDef_AttrDef::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_._has_bits_),
    0, // no _extensions_
    7, 56,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967168,  // skipmap
    offsetof(decltype(_table_), field_entries),
    7,  // num_field_entries
    2,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    OpDef_AttrDef_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::opencv_tensorflow::OpDef_AttrDef>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    {::_pbi::TcParser::MiniParse, {}},
    // string name = 1;
    {::_pbi::TcParser::FastUS1,
     {10, 0, 0, PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.name_)}},
    // string type = 2;
    {::_pbi::TcParser::FastUS1,
     {18, 1, 0, PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.type_)}},
    // .opencv_tensorflow.AttrValue default_value = 3;
    {::_pbi::TcParser::FastMtS1,
     {26, 3, 0, PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.default_value_)}},
    // string description = 4;
    {::_pbi::TcParser::FastUS1,
     {34, 2, 0, PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.description_)}},
    // bool has_minimum = 5;
    {::_pbi::TcParser::SingularVarintNoZag1<bool, offsetof(OpDef_AttrDef, _impl_.has_minimum_), 6>(),
     {40, 6, 0, PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.has_minimum_)}},
    // int64 minimum = 6;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(OpDef_AttrDef, _impl_.minimum_), 5>(),
     {48, 5, 0, PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.minimum_)}},
    // .opencv_tensorflow.AttrValue allowed_values = 7;
    {::_pbi::TcParser::FastMtS1,
     {58, 4, 1, PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.allowed_values_)}},
  }}, {{
    65535, 65535
  }}, {{
    // string name = 1;
    {PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // string type = 2;
    {PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.type_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // .opencv_tensorflow.AttrValue default_value = 3;
    {PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.default_value_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // string description = 4;
    {PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.description_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // bool has_minimum = 5;
    {PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.has_minimum_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // int64 minimum = 6;
    {PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.minimum_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    // .opencv_tensorflow.AttrValue allowed_values = 7;
    {PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.allowed_values_), _Internal::kHasBitsOffset + 4, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::AttrValue>()},
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::AttrValue>()},
  }},
  {{
    "\37\4\4\0\13\0\0\0"
    "opencv_tensorflow.OpDef.AttrDef"
    "name"
    "type"
    "description"
  }},
};
PROTOBUF_NOINLINE void OpDef_AttrDef::Clear() {
// @@protoc_insertion_point(message_clear_start:opencv_tensorflow.OpDef.AttrDef)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if ((cached_has_bits & 0x0000001fU) != 0) {
    if ((cached_has_bits & 0x00000001U) != 0) {
      _impl_.name_.ClearNonDefaultToEmpty();
    }
    if ((cached_has_bits & 0x00000002U) != 0) {
      _impl_.type_.ClearNonDefaultToEmpty();
    }
    if ((cached_has_bits & 0x00000004U) != 0) {
      _impl_.description_.ClearNonDefaultToEmpty();
    }
    if ((cached_has_bits & 0x00000008U) != 0) {
      ABSL_DCHECK(_impl_.default_value_ != nullptr);
      _impl_.default_value_->Clear();
    }
    if ((cached_has_bits & 0x00000010U) != 0) {
      ABSL_DCHECK(_impl_.allowed_values_ != nullptr);
      _impl_.allowed_values_->Clear();
    }
  }
  if ((cached_has_bits & 0x00000060U) != 0) {
    ::memset(&_impl_.minimum_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.has_minimum_) -
        reinterpret_cast<char*>(&_impl_.minimum_)) + sizeof(_impl_.has_minimum_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL OpDef_AttrDef::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const OpDef_AttrDef& this_ = static_cast<const OpDef_AttrDef&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL OpDef_AttrDef::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const OpDef_AttrDef& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opencv_tensorflow.OpDef.AttrDef)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  // string name = 1;
  if ((this_._impl_._has_bits_[0] & 0x00000001U) != 0) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.AttrDef.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // string type = 2;
  if ((this_._impl_._has_bits_[0] & 0x00000002U) != 0) {
    if (!this_._internal_type().empty()) {
      const ::std::string& _s = this_._internal_type();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.AttrDef.type");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  cached_has_bits = this_._impl_._has_bits_[0];
  // .opencv_tensorflow.AttrValue default_value = 3;
  if ((cached_has_bits & 0x00000008U) != 0) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        3, *this_._impl_.default_value_, this_._impl_.default_value_->GetCachedSize(), target,
        stream);
  }

  // string description = 4;
  if ((cached_has_bits & 0x00000004U) != 0) {
    if (!this_._internal_description().empty()) {
      const ::std::string& _s = this_._internal_description();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.AttrDef.description");
      target = stream->WriteStringMaybeAliased(4, _s, target);
    }
  }

  // bool has_minimum = 5;
  if ((cached_has_bits & 0x00000040U) != 0) {
    if (this_._internal_has_minimum() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          5, this_._internal_has_minimum(), target);
    }
  }

  // int64 minimum = 6;
  if ((cached_has_bits & 0x00000020U) != 0) {
    if (this_._internal_minimum() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<6>(
              stream, this_._internal_minimum(), target);
    }
  }

  // .opencv_tensorflow.AttrValue allowed_values = 7;
  if ((cached_has_bits & 0x00000010U) != 0) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        7, *this_._impl_.allowed_values_, this_._impl_.allowed_values_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opencv_tensorflow.OpDef.AttrDef)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t OpDef_AttrDef::ByteSizeLong(const MessageLite& base) {
  const OpDef_AttrDef& this_ = static_cast<const OpDef_AttrDef&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t OpDef_AttrDef::ByteSizeLong() const {
  const OpDef_AttrDef& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opencv_tensorflow.OpDef.AttrDef)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if ((cached_has_bits & 0x0000007fU) != 0) {
    // string name = 1;
    if ((cached_has_bits & 0x00000001U) != 0) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // string type = 2;
    if ((cached_has_bits & 0x00000002U) != 0) {
      if (!this_._internal_type().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_type());
      }
    }
    // string description = 4;
    if ((cached_has_bits & 0x00000004U) != 0) {
      if (!this_._internal_description().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_description());
      }
    }
    // .opencv_tensorflow.AttrValue default_value = 3;
    if ((cached_has_bits & 0x00000008U) != 0) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.default_value_);
    }
    // .opencv_tensorflow.AttrValue allowed_values = 7;
    if ((cached_has_bits & 0x00000010U) != 0) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.allowed_values_);
    }
    // int64 minimum = 6;
    if ((cached_has_bits & 0x00000020U) != 0) {
      if (this_._internal_minimum() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_minimum());
      }
    }
    // bool has_minimum = 5;
    if ((cached_has_bits & 0x00000040U) != 0) {
      if (this_._internal_has_minimum() != 0) {
        total_size += 2;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void OpDef_AttrDef::MergeImpl(::google::protobuf::MessageLite& to_msg, const ::google::protobuf::MessageLite& from_msg) {
  auto* const _this = static_cast<OpDef_AttrDef*>(&to_msg);
  auto& from = static_cast<const OpDef_AttrDef&>(from_msg);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    from.VerifyHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:opencv_tensorflow.OpDef.AttrDef)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if ((cached_has_bits & 0x0000007fU) != 0) {
    if ((cached_has_bits & 0x00000001U) != 0) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if ((cached_has_bits & 0x00000002U) != 0) {
      if (!from._internal_type().empty()) {
        _this->_internal_set_type(from._internal_type());
      } else {
        if (_this->_impl_.type_.IsDefault()) {
          _this->_internal_set_type("");
        }
      }
    }
    if ((cached_has_bits & 0x00000004U) != 0) {
      if (!from._internal_description().empty()) {
        _this->_internal_set_description(from._internal_description());
      } else {
        if (_this->_impl_.description_.IsDefault()) {
          _this->_internal_set_description("");
        }
      }
    }
    if ((cached_has_bits & 0x00000008U) != 0) {
      ABSL_DCHECK(from._impl_.default_value_ != nullptr);
      if (_this->_impl_.default_value_ == nullptr) {
        _this->_impl_.default_value_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.default_value_);
      } else {
        _this->_impl_.default_value_->MergeFrom(*from._impl_.default_value_);
      }
    }
    if ((cached_has_bits & 0x00000010U) != 0) {
      ABSL_DCHECK(from._impl_.allowed_values_ != nullptr);
      if (_this->_impl_.allowed_values_ == nullptr) {
        _this->_impl_.allowed_values_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.allowed_values_);
      } else {
        _this->_impl_.allowed_values_->MergeFrom(*from._impl_.allowed_values_);
      }
    }
    if ((cached_has_bits & 0x00000020U) != 0) {
      if (from._internal_minimum() != 0) {
        _this->_impl_.minimum_ = from._impl_.minimum_;
      }
    }
    if ((cached_has_bits & 0x00000040U) != 0) {
      if (from._internal_has_minimum() != 0) {
        _this->_impl_.has_minimum_ = from._impl_.has_minimum_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void OpDef_AttrDef::CopyFrom(const OpDef_AttrDef& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:opencv_tensorflow.OpDef.AttrDef)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void OpDef_AttrDef::InternalSwap(OpDef_AttrDef* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.type_, &other->_impl_.type_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.description_, &other->_impl_.description_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.has_minimum_)
      + sizeof(OpDef_AttrDef::_impl_.has_minimum_)
      - PROTOBUF_FIELD_OFFSET(OpDef_AttrDef, _impl_.default_value_)>(
          reinterpret_cast<char*>(&_impl_.default_value_),
          reinterpret_cast<char*>(&other->_impl_.default_value_));
}

::google::protobuf::Metadata OpDef_AttrDef::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class OpDef::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<OpDef>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(OpDef, _impl_._has_bits_);
};

OpDef::OpDef(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, OpDef_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opencv_tensorflow.OpDef)
}
PROTOBUF_NDEBUG_INLINE OpDef::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opencv_tensorflow::OpDef& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        input_arg_{visibility, arena, from.input_arg_},
        output_arg_{visibility, arena, from.output_arg_},
        attr_{visibility, arena, from.attr_},
        name_(arena, from.name_),
        summary_(arena, from.summary_),
        description_(arena, from.description_) {}

OpDef::OpDef(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const OpDef& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, OpDef_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  OpDef* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.deprecation_ = ((cached_has_bits & 0x00000008U) != 0)
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.deprecation_)
                : nullptr;
  ::memcpy(reinterpret_cast<char *>(&_impl_) +
               offsetof(Impl_, is_aggregate_),
           reinterpret_cast<const char *>(&from._impl_) +
               offsetof(Impl_, is_aggregate_),
           offsetof(Impl_, allows_uninitialized_input_) -
               offsetof(Impl_, is_aggregate_) +
               sizeof(Impl_::allows_uninitialized_input_));

  // @@protoc_insertion_point(copy_constructor:opencv_tensorflow.OpDef)
}
PROTOBUF_NDEBUG_INLINE OpDef::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        input_arg_{visibility, arena},
        output_arg_{visibility, arena},
        attr_{visibility, arena},
        name_(arena),
        summary_(arena),
        description_(arena) {}

inline void OpDef::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char *>(&_impl_) +
               offsetof(Impl_, deprecation_),
           0,
           offsetof(Impl_, allows_uninitialized_input_) -
               offsetof(Impl_, deprecation_) +
               sizeof(Impl_::allows_uninitialized_input_));
}
OpDef::~OpDef() {
  // @@protoc_insertion_point(destructor:opencv_tensorflow.OpDef)
  SharedDtor(*this);
}
inline void OpDef::SharedDtor(MessageLite& self) {
  OpDef& this_ = static_cast<OpDef&>(self);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.summary_.Destroy();
  this_._impl_.description_.Destroy();
  delete this_._impl_.deprecation_;
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL OpDef::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) OpDef(arena);
}
constexpr auto OpDef::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(OpDef, _impl_.input_arg_) +
          decltype(OpDef::_impl_.input_arg_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
      PROTOBUF_FIELD_OFFSET(OpDef, _impl_.output_arg_) +
          decltype(OpDef::_impl_.output_arg_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
      PROTOBUF_FIELD_OFFSET(OpDef, _impl_.attr_) +
          decltype(OpDef::_impl_.attr_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::CopyInit(
        sizeof(OpDef), alignof(OpDef), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&OpDef::PlacementNew_,
                                 sizeof(OpDef),
                                 alignof(OpDef));
  }
}
constexpr auto OpDef::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_OpDef_default_instance_._instance,
          &_table_.header,
          nullptr,  // OnDemandRegisterArenaDtor
          nullptr,  // IsInitialized
          &OpDef::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<OpDef>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &OpDef::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<OpDef>(), &OpDef::ByteSizeLong,
              &OpDef::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(OpDef, _impl_._cached_size_),
          false,
      },
      &OpDef::kDescriptorMethods,
      &descriptor_table_op_5fdef_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull OpDef_class_data_ =
        OpDef::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
OpDef::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&OpDef_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(OpDef_class_data_.tc_table);
  return OpDef_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<4, 11, 4, 62, 2>
OpDef::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(OpDef, _impl_._has_bits_),
    0, // no _extensions_
    19, 120,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294475584,  // skipmap
    offsetof(decltype(_table_), field_entries),
    11,  // num_field_entries
    4,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    OpDef_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::opencv_tensorflow::OpDef>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // bool is_aggregate = 16;
    {::_pbi::TcParser::FastV8S2,
     {384, 4, 0, PROTOBUF_FIELD_OFFSET(OpDef, _impl_.is_aggregate_)}},
    // string name = 1;
    {::_pbi::TcParser::FastUS1,
     {10, 0, 0, PROTOBUF_FIELD_OFFSET(OpDef, _impl_.name_)}},
    // repeated .opencv_tensorflow.OpDef.ArgDef input_arg = 2;
    {::_pbi::TcParser::FastMtR1,
     {18, 63, 0, PROTOBUF_FIELD_OFFSET(OpDef, _impl_.input_arg_)}},
    // repeated .opencv_tensorflow.OpDef.ArgDef output_arg = 3;
    {::_pbi::TcParser::FastMtR1,
     {26, 63, 1, PROTOBUF_FIELD_OFFSET(OpDef, _impl_.output_arg_)}},
    // repeated .opencv_tensorflow.OpDef.AttrDef attr = 4;
    {::_pbi::TcParser::FastMtR1,
     {34, 63, 2, PROTOBUF_FIELD_OFFSET(OpDef, _impl_.attr_)}},
    // string summary = 5;
    {::_pbi::TcParser::FastUS1,
     {42, 1, 0, PROTOBUF_FIELD_OFFSET(OpDef, _impl_.summary_)}},
    // string description = 6;
    {::_pbi::TcParser::FastUS1,
     {50, 2, 0, PROTOBUF_FIELD_OFFSET(OpDef, _impl_.description_)}},
    {::_pbi::TcParser::MiniParse, {}},
    // .opencv_tensorflow.OpDeprecation deprecation = 8;
    {::_pbi::TcParser::FastMtS1,
     {66, 3, 3, PROTOBUF_FIELD_OFFSET(OpDef, _impl_.deprecation_)}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
    {::_pbi::TcParser::MiniParse, {}},
  }}, {{
    65535, 65535
  }}, {{
    // string name = 1;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // repeated .opencv_tensorflow.OpDef.ArgDef input_arg = 2;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.input_arg_), -1, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    // repeated .opencv_tensorflow.OpDef.ArgDef output_arg = 3;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.output_arg_), -1, 1, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    // repeated .opencv_tensorflow.OpDef.AttrDef attr = 4;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.attr_), -1, 2, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
    // string summary = 5;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.summary_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // string description = 6;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.description_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    // .opencv_tensorflow.OpDeprecation deprecation = 8;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.deprecation_), _Internal::kHasBitsOffset + 3, 3, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    // bool is_aggregate = 16;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.is_aggregate_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // bool is_stateful = 17;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.is_stateful_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // bool is_commutative = 18;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.is_commutative_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
    // bool allows_uninitialized_input = 19;
    {PROTOBUF_FIELD_OFFSET(OpDef, _impl_.allows_uninitialized_input_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kBool)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::OpDef_ArgDef>()},
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::OpDef_ArgDef>()},
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::OpDef_AttrDef>()},
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::OpDeprecation>()},
  }},
  {{
    "\27\4\0\0\0\7\13\0\0\0\0\0\0\0\0\0"
    "opencv_tensorflow.OpDef"
    "name"
    "summary"
    "description"
  }},
};
PROTOBUF_NOINLINE void OpDef::Clear() {
// @@protoc_insertion_point(message_clear_start:opencv_tensorflow.OpDef)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  _impl_.input_arg_.Clear();
  _impl_.output_arg_.Clear();
  _impl_.attr_.Clear();
  cached_has_bits = _impl_._has_bits_[0];
  if ((cached_has_bits & 0x0000000fU) != 0) {
    if ((cached_has_bits & 0x00000001U) != 0) {
      _impl_.name_.ClearNonDefaultToEmpty();
    }
    if ((cached_has_bits & 0x00000002U) != 0) {
      _impl_.summary_.ClearNonDefaultToEmpty();
    }
    if ((cached_has_bits & 0x00000004U) != 0) {
      _impl_.description_.ClearNonDefaultToEmpty();
    }
    if ((cached_has_bits & 0x00000008U) != 0) {
      ABSL_DCHECK(_impl_.deprecation_ != nullptr);
      _impl_.deprecation_->Clear();
    }
  }
  ::memset(&_impl_.is_aggregate_, 0, static_cast<::size_t>(
      reinterpret_cast<char*>(&_impl_.allows_uninitialized_input_) -
      reinterpret_cast<char*>(&_impl_.is_aggregate_)) + sizeof(_impl_.allows_uninitialized_input_));
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL OpDef::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const OpDef& this_ = static_cast<const OpDef&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL OpDef::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const OpDef& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opencv_tensorflow.OpDef)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  // string name = 1;
  if ((this_._impl_._has_bits_[0] & 0x00000001U) != 0) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // repeated .opencv_tensorflow.OpDef.ArgDef input_arg = 2;
  for (unsigned i = 0, n = static_cast<unsigned>(
                           this_._internal_input_arg_size());
       i < n; i++) {
    const auto& repfield = this_._internal_input_arg().Get(i);
    target =
        ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
            2, repfield, repfield.GetCachedSize(),
            target, stream);
  }

  // repeated .opencv_tensorflow.OpDef.ArgDef output_arg = 3;
  for (unsigned i = 0, n = static_cast<unsigned>(
                           this_._internal_output_arg_size());
       i < n; i++) {
    const auto& repfield = this_._internal_output_arg().Get(i);
    target =
        ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
            3, repfield, repfield.GetCachedSize(),
            target, stream);
  }

  // repeated .opencv_tensorflow.OpDef.AttrDef attr = 4;
  for (unsigned i = 0, n = static_cast<unsigned>(
                           this_._internal_attr_size());
       i < n; i++) {
    const auto& repfield = this_._internal_attr().Get(i);
    target =
        ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
            4, repfield, repfield.GetCachedSize(),
            target, stream);
  }

  // string summary = 5;
  if ((this_._impl_._has_bits_[0] & 0x00000002U) != 0) {
    if (!this_._internal_summary().empty()) {
      const ::std::string& _s = this_._internal_summary();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.summary");
      target = stream->WriteStringMaybeAliased(5, _s, target);
    }
  }

  // string description = 6;
  if ((this_._impl_._has_bits_[0] & 0x00000004U) != 0) {
    if (!this_._internal_description().empty()) {
      const ::std::string& _s = this_._internal_description();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDef.description");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  cached_has_bits = this_._impl_._has_bits_[0];
  // .opencv_tensorflow.OpDeprecation deprecation = 8;
  if ((cached_has_bits & 0x00000008U) != 0) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        8, *this_._impl_.deprecation_, this_._impl_.deprecation_->GetCachedSize(), target,
        stream);
  }

  // bool is_aggregate = 16;
  if ((cached_has_bits & 0x00000010U) != 0) {
    if (this_._internal_is_aggregate() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          16, this_._internal_is_aggregate(), target);
    }
  }

  // bool is_stateful = 17;
  if ((cached_has_bits & 0x00000020U) != 0) {
    if (this_._internal_is_stateful() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          17, this_._internal_is_stateful(), target);
    }
  }

  // bool is_commutative = 18;
  if ((cached_has_bits & 0x00000040U) != 0) {
    if (this_._internal_is_commutative() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          18, this_._internal_is_commutative(), target);
    }
  }

  // bool allows_uninitialized_input = 19;
  if ((cached_has_bits & 0x00000080U) != 0) {
    if (this_._internal_allows_uninitialized_input() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteBoolToArray(
          19, this_._internal_allows_uninitialized_input(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opencv_tensorflow.OpDef)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t OpDef::ByteSizeLong(const MessageLite& base) {
  const OpDef& this_ = static_cast<const OpDef&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t OpDef::ByteSizeLong() const {
  const OpDef& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opencv_tensorflow.OpDef)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated .opencv_tensorflow.OpDef.ArgDef input_arg = 2;
    {
      total_size += 1UL * this_._internal_input_arg_size();
      for (const auto& msg : this_._internal_input_arg()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // repeated .opencv_tensorflow.OpDef.ArgDef output_arg = 3;
    {
      total_size += 1UL * this_._internal_output_arg_size();
      for (const auto& msg : this_._internal_output_arg()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // repeated .opencv_tensorflow.OpDef.AttrDef attr = 4;
    {
      total_size += 1UL * this_._internal_attr_size();
      for (const auto& msg : this_._internal_attr()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  cached_has_bits = this_._impl_._has_bits_[0];
  if ((cached_has_bits & 0x000000ffU) != 0) {
    // string name = 1;
    if ((cached_has_bits & 0x00000001U) != 0) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // string summary = 5;
    if ((cached_has_bits & 0x00000002U) != 0) {
      if (!this_._internal_summary().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_summary());
      }
    }
    // string description = 6;
    if ((cached_has_bits & 0x00000004U) != 0) {
      if (!this_._internal_description().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_description());
      }
    }
    // .opencv_tensorflow.OpDeprecation deprecation = 8;
    if ((cached_has_bits & 0x00000008U) != 0) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.deprecation_);
    }
    // bool is_aggregate = 16;
    if ((cached_has_bits & 0x00000010U) != 0) {
      if (this_._internal_is_aggregate() != 0) {
        total_size += 3;
      }
    }
    // bool is_stateful = 17;
    if ((cached_has_bits & 0x00000020U) != 0) {
      if (this_._internal_is_stateful() != 0) {
        total_size += 3;
      }
    }
    // bool is_commutative = 18;
    if ((cached_has_bits & 0x00000040U) != 0) {
      if (this_._internal_is_commutative() != 0) {
        total_size += 3;
      }
    }
    // bool allows_uninitialized_input = 19;
    if ((cached_has_bits & 0x00000080U) != 0) {
      if (this_._internal_allows_uninitialized_input() != 0) {
        total_size += 3;
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void OpDef::MergeImpl(::google::protobuf::MessageLite& to_msg, const ::google::protobuf::MessageLite& from_msg) {
  auto* const _this = static_cast<OpDef*>(&to_msg);
  auto& from = static_cast<const OpDef&>(from_msg);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    from.VerifyHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:opencv_tensorflow.OpDef)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  _this->_internal_mutable_input_arg()->MergeFrom(
      from._internal_input_arg());
  _this->_internal_mutable_output_arg()->MergeFrom(
      from._internal_output_arg());
  _this->_internal_mutable_attr()->MergeFrom(
      from._internal_attr());
  cached_has_bits = from._impl_._has_bits_[0];
  if ((cached_has_bits & 0x000000ffU) != 0) {
    if ((cached_has_bits & 0x00000001U) != 0) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if ((cached_has_bits & 0x00000002U) != 0) {
      if (!from._internal_summary().empty()) {
        _this->_internal_set_summary(from._internal_summary());
      } else {
        if (_this->_impl_.summary_.IsDefault()) {
          _this->_internal_set_summary("");
        }
      }
    }
    if ((cached_has_bits & 0x00000004U) != 0) {
      if (!from._internal_description().empty()) {
        _this->_internal_set_description(from._internal_description());
      } else {
        if (_this->_impl_.description_.IsDefault()) {
          _this->_internal_set_description("");
        }
      }
    }
    if ((cached_has_bits & 0x00000008U) != 0) {
      ABSL_DCHECK(from._impl_.deprecation_ != nullptr);
      if (_this->_impl_.deprecation_ == nullptr) {
        _this->_impl_.deprecation_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.deprecation_);
      } else {
        _this->_impl_.deprecation_->MergeFrom(*from._impl_.deprecation_);
      }
    }
    if ((cached_has_bits & 0x00000010U) != 0) {
      if (from._internal_is_aggregate() != 0) {
        _this->_impl_.is_aggregate_ = from._impl_.is_aggregate_;
      }
    }
    if ((cached_has_bits & 0x00000020U) != 0) {
      if (from._internal_is_stateful() != 0) {
        _this->_impl_.is_stateful_ = from._impl_.is_stateful_;
      }
    }
    if ((cached_has_bits & 0x00000040U) != 0) {
      if (from._internal_is_commutative() != 0) {
        _this->_impl_.is_commutative_ = from._impl_.is_commutative_;
      }
    }
    if ((cached_has_bits & 0x00000080U) != 0) {
      if (from._internal_allows_uninitialized_input() != 0) {
        _this->_impl_.allows_uninitialized_input_ = from._impl_.allows_uninitialized_input_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void OpDef::CopyFrom(const OpDef& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:opencv_tensorflow.OpDef)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void OpDef::InternalSwap(OpDef* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.input_arg_.InternalSwap(&other->_impl_.input_arg_);
  _impl_.output_arg_.InternalSwap(&other->_impl_.output_arg_);
  _impl_.attr_.InternalSwap(&other->_impl_.attr_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.summary_, &other->_impl_.summary_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.description_, &other->_impl_.description_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(OpDef, _impl_.allows_uninitialized_input_)
      + sizeof(OpDef::_impl_.allows_uninitialized_input_)
      - PROTOBUF_FIELD_OFFSET(OpDef, _impl_.deprecation_)>(
          reinterpret_cast<char*>(&_impl_.deprecation_),
          reinterpret_cast<char*>(&other->_impl_.deprecation_));
}

::google::protobuf::Metadata OpDef::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class OpDeprecation::_Internal {
 public:
  using HasBits =
      decltype(::std::declval<OpDeprecation>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(OpDeprecation, _impl_._has_bits_);
};

OpDeprecation::OpDeprecation(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, OpDeprecation_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opencv_tensorflow.OpDeprecation)
}
PROTOBUF_NDEBUG_INLINE OpDeprecation::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opencv_tensorflow::OpDeprecation& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        explanation_(arena, from.explanation_) {}

OpDeprecation::OpDeprecation(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const OpDeprecation& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, OpDeprecation_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  OpDeprecation* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  _impl_.version_ = from._impl_.version_;

  // @@protoc_insertion_point(copy_constructor:opencv_tensorflow.OpDeprecation)
}
PROTOBUF_NDEBUG_INLINE OpDeprecation::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        explanation_(arena) {}

inline void OpDeprecation::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.version_ = {};
}
OpDeprecation::~OpDeprecation() {
  // @@protoc_insertion_point(destructor:opencv_tensorflow.OpDeprecation)
  SharedDtor(*this);
}
inline void OpDeprecation::SharedDtor(MessageLite& self) {
  OpDeprecation& this_ = static_cast<OpDeprecation&>(self);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.explanation_.Destroy();
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL OpDeprecation::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) OpDeprecation(arena);
}
constexpr auto OpDeprecation::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(OpDeprecation),
                                            alignof(OpDeprecation));
}
constexpr auto OpDeprecation::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_OpDeprecation_default_instance_._instance,
          &_table_.header,
          nullptr,  // OnDemandRegisterArenaDtor
          nullptr,  // IsInitialized
          &OpDeprecation::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<OpDeprecation>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &OpDeprecation::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<OpDeprecation>(), &OpDeprecation::ByteSizeLong,
              &OpDeprecation::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(OpDeprecation, _impl_._cached_size_),
          false,
      },
      &OpDeprecation::kDescriptorMethods,
      &descriptor_table_op_5fdef_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull OpDeprecation_class_data_ =
        OpDeprecation::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
OpDeprecation::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&OpDeprecation_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(OpDeprecation_class_data_.tc_table);
  return OpDeprecation_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<1, 2, 0, 51, 2>
OpDeprecation::_table_ = {
  {
    PROTOBUF_FIELD_OFFSET(OpDeprecation, _impl_._has_bits_),
    0, // no _extensions_
    2, 8,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967292,  // skipmap
    offsetof(decltype(_table_), field_entries),
    2,  // num_field_entries
    0,  // num_aux_entries
    offsetof(decltype(_table_), field_names),  // no aux_entries
    OpDeprecation_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::opencv_tensorflow::OpDeprecation>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // string explanation = 2;
    {::_pbi::TcParser::FastUS1,
     {18, 0, 0, PROTOBUF_FIELD_OFFSET(OpDeprecation, _impl_.explanation_)}},
    // int32 version = 1;
    {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(OpDeprecation, _impl_.version_), 1>(),
     {8, 1, 0, PROTOBUF_FIELD_OFFSET(OpDeprecation, _impl_.version_)}},
  }}, {{
    65535, 65535
  }}, {{
    // int32 version = 1;
    {PROTOBUF_FIELD_OFFSET(OpDeprecation, _impl_.version_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt32)},
    // string explanation = 2;
    {PROTOBUF_FIELD_OFFSET(OpDeprecation, _impl_.explanation_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
  }},
  // no aux_entries
  {{
    "\37\0\13\0\0\0\0\0"
    "opencv_tensorflow.OpDeprecation"
    "explanation"
  }},
};
PROTOBUF_NOINLINE void OpDeprecation::Clear() {
// @@protoc_insertion_point(message_clear_start:opencv_tensorflow.OpDeprecation)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if ((cached_has_bits & 0x00000001U) != 0) {
    _impl_.explanation_.ClearNonDefaultToEmpty();
  }
  _impl_.version_ = 0;
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL OpDeprecation::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const OpDeprecation& this_ = static_cast<const OpDeprecation&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL OpDeprecation::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const OpDeprecation& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opencv_tensorflow.OpDeprecation)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  // int32 version = 1;
  if ((this_._impl_._has_bits_[0] & 0x00000002U) != 0) {
    if (this_._internal_version() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt32ToArrayWithField<1>(
              stream, this_._internal_version(), target);
    }
  }

  // string explanation = 2;
  if ((this_._impl_._has_bits_[0] & 0x00000001U) != 0) {
    if (!this_._internal_explanation().empty()) {
      const ::std::string& _s = this_._internal_explanation();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "opencv_tensorflow.OpDeprecation.explanation");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opencv_tensorflow.OpDeprecation)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t OpDeprecation::ByteSizeLong(const MessageLite& base) {
  const OpDeprecation& this_ = static_cast<const OpDeprecation&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t OpDeprecation::ByteSizeLong() const {
  const OpDeprecation& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opencv_tensorflow.OpDeprecation)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if ((cached_has_bits & 0x00000003U) != 0) {
    // string explanation = 2;
    if ((cached_has_bits & 0x00000001U) != 0) {
      if (!this_._internal_explanation().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_explanation());
      }
    }
    // int32 version = 1;
    if ((cached_has_bits & 0x00000002U) != 0) {
      if (this_._internal_version() != 0) {
        total_size += ::_pbi::WireFormatLite::Int32SizePlusOne(
            this_._internal_version());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void OpDeprecation::MergeImpl(::google::protobuf::MessageLite& to_msg, const ::google::protobuf::MessageLite& from_msg) {
  auto* const _this = static_cast<OpDeprecation*>(&to_msg);
  auto& from = static_cast<const OpDeprecation&>(from_msg);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    from.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:opencv_tensorflow.OpDeprecation)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if ((cached_has_bits & 0x00000003U) != 0) {
    if ((cached_has_bits & 0x00000001U) != 0) {
      if (!from._internal_explanation().empty()) {
        _this->_internal_set_explanation(from._internal_explanation());
      } else {
        if (_this->_impl_.explanation_.IsDefault()) {
          _this->_internal_set_explanation("");
        }
      }
    }
    if ((cached_has_bits & 0x00000002U) != 0) {
      if (from._internal_version() != 0) {
        _this->_impl_.version_ = from._impl_.version_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void OpDeprecation::CopyFrom(const OpDeprecation& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:opencv_tensorflow.OpDeprecation)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void OpDeprecation::InternalSwap(OpDeprecation* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.explanation_, &other->_impl_.explanation_, arena);
  swap(_impl_.version_, other->_impl_.version_);
}

::google::protobuf::Metadata OpDeprecation::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

class OpList::_Internal {
 public:
};

OpList::OpList(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, OpList_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:opencv_tensorflow.OpList)
}
PROTOBUF_NDEBUG_INLINE OpList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::opencv_tensorflow::OpList& from_msg)
      : op_{visibility, arena, from.op_},
        _cached_size_{0} {}

OpList::OpList(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const OpList& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, OpList_class_data_.base()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  OpList* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:opencv_tensorflow.OpList)
}
PROTOBUF_NDEBUG_INLINE OpList::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : op_{visibility, arena},
        _cached_size_{0} {}

inline void OpList::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
OpList::~OpList() {
  // @@protoc_insertion_point(destructor:opencv_tensorflow.OpList)
  SharedDtor(*this);
}
inline void OpList::SharedDtor(MessageLite& self) {
  OpList& this_ = static_cast<OpList&>(self);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.~Impl_();
}

inline void* PROTOBUF_NONNULL OpList::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) OpList(arena);
}
constexpr auto OpList::InternalNewImpl_() {
  constexpr auto arena_bits = ::google::protobuf::internal::EncodePlacementArenaOffsets({
      PROTOBUF_FIELD_OFFSET(OpList, _impl_.op_) +
          decltype(OpList::_impl_.op_)::
              InternalGetArenaOffset(
                  ::google::protobuf::Message::internal_visibility()),
  });
  if (arena_bits.has_value()) {
    return ::google::protobuf::internal::MessageCreator::ZeroInit(
        sizeof(OpList), alignof(OpList), *arena_bits);
  } else {
    return ::google::protobuf::internal::MessageCreator(&OpList::PlacementNew_,
                                 sizeof(OpList),
                                 alignof(OpList));
  }
}
constexpr auto OpList::InternalGenerateClassData_() {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &_OpList_default_instance_._instance,
          &_table_.header,
          nullptr,  // OnDemandRegisterArenaDtor
          nullptr,  // IsInitialized
          &OpList::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<OpList>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &OpList::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<OpList>(), &OpList::ByteSizeLong,
              &OpList::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(OpList, _impl_._cached_size_),
          false,
      },
      &OpList::kDescriptorMethods,
      &descriptor_table_op_5fdef_2eproto,
      nullptr,  // tracker
  };
}

PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull OpList_class_data_ =
        OpList::InternalGenerateClassData_();

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
OpList::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&OpList_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(OpList_class_data_.tc_table);
  return OpList_class_data_.base();
}
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1
const ::_pbi::TcParseTable<0, 1, 1, 0, 2>
OpList::_table_ = {
  {
    0,  // no _has_bits_
    0, // no _extensions_
    1, 0,  // max_field_number, fast_idx_mask
    offsetof(decltype(_table_), field_lookup_table),
    4294967294,  // skipmap
    offsetof(decltype(_table_), field_entries),
    1,  // num_field_entries
    1,  // num_aux_entries
    offsetof(decltype(_table_), aux_entries),
    OpList_class_data_.base(),
    nullptr,  // post_loop_handler
    ::_pbi::TcParser::GenericFallback,  // fallback
    #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
    ::_pbi::TcParser::GetTable<::opencv_tensorflow::OpList>(),  // to_prefetch
    #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
  }, {{
    // repeated .opencv_tensorflow.OpDef op = 1;
    {::_pbi::TcParser::FastMtR1,
     {10, 63, 0, PROTOBUF_FIELD_OFFSET(OpList, _impl_.op_)}},
  }}, {{
    65535, 65535
  }}, {{
    // repeated .opencv_tensorflow.OpDef op = 1;
    {PROTOBUF_FIELD_OFFSET(OpList, _impl_.op_), 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
  }},
  {{
      {::_pbi::TcParser::GetTable<::opencv_tensorflow::OpDef>()},
  }},
  {{
  }},
};
PROTOBUF_NOINLINE void OpList::Clear() {
// @@protoc_insertion_point(message_clear_start:opencv_tensorflow.OpList)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  _impl_.op_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL OpList::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const OpList& this_ = static_cast<const OpList&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL OpList::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const OpList& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    this_.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:opencv_tensorflow.OpList)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  // repeated .opencv_tensorflow.OpDef op = 1;
  for (unsigned i = 0, n = static_cast<unsigned>(
                           this_._internal_op_size());
       i < n; i++) {
    const auto& repfield = this_._internal_op().Get(i);
    target =
        ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
            1, repfield, repfield.GetCachedSize(),
            target, stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:opencv_tensorflow.OpList)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t OpList::ByteSizeLong(const MessageLite& base) {
  const OpList& this_ = static_cast<const OpList&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t OpList::ByteSizeLong() const {
  const OpList& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:opencv_tensorflow.OpList)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
   {
    // repeated .opencv_tensorflow.OpDef op = 1;
    {
      total_size += 1UL * this_._internal_op_size();
      for (const auto& msg : this_._internal_op()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void OpList::MergeImpl(::google::protobuf::MessageLite& to_msg, const ::google::protobuf::MessageLite& from_msg) {
  auto* const _this = static_cast<OpList*>(&to_msg);
  auto& from = static_cast<const OpList&>(from_msg);
  if constexpr (::_pbi::DebugHardenVerifyHasBitConsistency()) {
    from.VerifyHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:opencv_tensorflow.OpList)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void) cached_has_bits;

  _this->_internal_mutable_op()->MergeFrom(
      from._internal_op());
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(from._internal_metadata_);
}

void OpList::CopyFrom(const OpList& from) {
// @@protoc_insertion_point(class_specific_copy_from_start:opencv_tensorflow.OpList)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void OpList::InternalSwap(OpList* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  _impl_.op_.InternalSwap(&other->_impl_.op_);
}

::google::protobuf::Metadata OpList::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace opencv_tensorflow
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_op_5fdef_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
